#
# spec file for package xpr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xpr
Version:        1.2.0
Release:        1.5
Summary:        Utility to print an X window dump
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xmuu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.3
BuildRequires:  pkgconfig(xproto) >= 7.0.17
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
xpr takes as input a window dump file produced by xwd
and formats it for output on various types of printers.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xdpr
%{_bindir}/xpr
%{_mandir}/man1/xdpr.1%{?ext_man}
%{_mandir}/man1/xpr.1%{?ext_man}

%changelog
* Mon Mar  4 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.0
  * Use memcpy() instead of memmove() when buffers are known not to overlap
  * Remove unnnecessary casts from malloc(), calloc(), and free() calls
  * No need to bzero() buffers allocated by calloc()
  * Add support for paper sizes other than 8.5 x 11 inches
  * gitlab CI: stop requiring Signed-off-by in commits
  * Modernize lseek() calls
  * configure: Use AC_SYS_LARGEFILE to enable large file support
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.0
  * Standardize indentation in validate_visual()
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Use time_t instead of long with time() & ctime()
  * xpr.man: remove duplicate "HP" from PaintJet XL Color name
  * xpr.man: show current version in footer instead of X11R6
  * Remove support for Digital LA100 dot matrix printer
  * Remove support for Digital LN03 laser printer
  * gitlab CI: add a basic build test
  * Fix spelling/wording issues
  * gitlab CI: Use ci-fairy image template
  * gitlab CI: enable Static Application Security Testing (SAST)
  * Build xz tarballs instead of bzip2
  * man pages: remove out-of-date COPYRIGHT section
  * xdpr.man: minor corrections
  * remove extra 3rd parameter to open()
* Fri Dec  3 2021 Dirk Müller <dmueller@suse.com>
- modernize spec-cleaner (move license to licensedir)
* Wed Apr  4 2018 sndirsch@suse.com
- Update to version 1.0.5
  * Remove unneeded uses of <math.h> & -lm
  * This is not a GNU project, so declare it foreign.
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * Remove old CVS id tags
  * Combine strings in usage message
  * Fix "missmatch" typo in error message
  * Print which option was in error along with usage message
  * Add -version option to print program version
  * More constification
  * Fix man page references to X(1) to use __miscmansuffix__
  * autogen.sh: use quoted string variables
  * Use strcmp() to compare strings and simplify options parser.
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.0.4:
  + Use memmove rather than bcopy
  + Add _X_NORETURN to usage() & leave() as suggested by gcc
  - Wmissing-noreturn
  + Add const attributes to fix gcc -Wwrite-strings warnings
  + Fix printf type warnings in LP64 builds
  + Define pixel mask constant as unsigned long
  + Refactor invalid depth error reporting to allow printf format
    checking
  + Replace gcc noreturn & printf attributes with macros from
    <X11/Xfuncproto.h>
  + Build system fixes.
- Add pkgconfig(xproto) BuildRequires: new dependency.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xpr from xorg-x11. Initial version: 1.0.3.
